@@ -1,2 +1,2 @@
 name = 'ringcentral_bot_framework'
-from .core.route import router
\ No newline at end of file
+from .core import frameworkInit
\ No newline at end of file
