@@ -2,7 +2,7 @@
 user auth
 """
 import time
-from .common import result
+from .common import result, getQueryParam
 from pydash import get
 
 def initUserAuth(
@@ -14,8 +14,9 @@ def initUserAuth(
 ):
   def userAuth(event):
     user = User()
-    user.auth(get(event, 'queryStringParameters.code'))
-    state = get(event, 'queryStringParameters.state') or ','
+    code = getQueryParam(event, 'code')
+    user.auth(code)
+    state = getQueryParam(event, 'state') or ','
     arr = state.split(',')
     groupId = get(arr, '[0]')
     botId = get(arr, '[1]')
